Toolbox for visualizing trajectories on a map using GPS data. Uses [TileMapBase](https://github.com/MatthewDaws/TileMapBase) as the backend for create map tiles.

# OpenStreetMaps
OpenStreetMaps data usage: https://www.openstreetmap.org/copyright
Tile usage is subject to constraints: https://operations.osmfoundation.org/policies/tiles/